function Plot_Globe_No_Debris
% This function plots the mission for the GTOC 9 intro. Note the
% following variables:
%   MJD_Start - start time of the simulation
%   AVI_Name - Name for AVI File
%   xPixels - Video Width (1280 for 720 resolution or 1920 for 1080)
%   Ratio - 16/9 is common for most videos
%   FPS - Frames per second (30 or 60)
%   SpeedRatio - Ratio between video and real time, 600 means 1 second of
%       video is 600 seconds of orbital time.
%   Tspan - Video length in seconds
%
% Written By: Brandon Jackson
% Date: 8/17/2017

%% Orbital Information
MJD_Start = 23437;
GMST0 = 4.89496121282306; % Set up a rotatable globe at J2000.0

% Video Setup
AVI_Name = 'Intro.avi';

%% Earth Properties
% Defines radius, rotation rate, and a datum time for J2000
erad    = 6371008.7714; % equatorial radius (meters)
erot    = 7.2921158553e-5; % earth rotation rate (radians/sec)

%% Location of initial camera view
city_Long = -88.94;
city_Lat = 47.12;
Long_Offset = wrapTo2Pi(GMST0 + erot*MJD_Start*24*60*60)*180/pi;

%% Video Parameters
% Figure Ratios and Resolution

xPixels = 1280;
FPS = 30; % frames per second

Ratio = 16/9;
yPixels = xPixels/Ratio;

% Frame Rate
SpeedRatio = 600; % 1 second of simulation time = SpeedRatio second of earth time

%% Figure and Globe Options
space_color = 'k';
npanels = 180;   % Number of globe panels around the equator deg/panel = 360/npanels
alpha   = 1; % globe transparency level, 1 = opaque, through 0 = invisible
% GMST0 = []; % Don't set up rotatable globe (ECEF)

% Image file based on this upload
% image_file = 'http://upload.wikimedia.org/wikipedia/commons/thumb/c/cd/Land_ocean_ice_2048.jpg/1024px-Land_ocean_ice_2048.jpg';

% Create figure and make full screen
f = figure('Color', space_color);
f.Units = 'pixels';
f.Resize = 'off';
f.MenuBar = 'none';
f.ToolBar = 'none';
f.Position = [50 50 xPixels yPixels];
hold on;

% Turn off the normal axes
set(gca, 'NextPlot','add', 'Visible','off');
axis equal;
axis auto;

% Set initial view
view(0,30);
axis vis3d;

%% Create the globe and Apply Texture Map
% This section of code was adapted from work uploaded on the Mathworks File
% Exchange by Ryan Gray.
% https://www.mathworks.com/matlabcentral/fileexchange/13823-3d-earth-example

EarthAxes = gca;

% Create a 3D meshgrid of the sphere points using the ellipsoid function
[x, y, z] = ellipsoid(0, 0, 0, erad, erad, erad, npanels);

globe = surf(x, y, -z, 'FaceColor', 'none', 'EdgeColor', 0.5*[1 1 1]);

% Rotate the globe by GMST0 radians
if ~isempty(GMST0)
    hgx = hgtransform;
    set(hgx,'Matrix', makehgtform('zrotate',Long_Offset*pi/180));
    set(globe,'Parent',hgx);
end

% Apply the texture map
% Load the map
cdata = imread('Image_XLarge.jpg');

% Set image as color data (cdata) property, and set face color to indicate
% a texturemap, which Matlab expects to be in cdata. Turn off the mesh edges.

set(globe, 'FaceColor', 'texturemap', 'CData', cdata, 'FaceAlpha', alpha, 'EdgeColor', 'none');

%% Now setup the initial view
axes(EarthAxes);
uistack(EarthAxes, 'bottom');
angle_PrimeMeridian = 90;

% Pan to desired view
az_Start = wrapTo360(angle_PrimeMeridian + city_Long + Long_Offset);
az_End = wrapTo360(az_Start - city_Long);
el_Start = city_Lat;
el_End = 30;
viewA_Start = 0.7507;
viewA_End = 6;
nSteps = 500;
view(az_Start, city_Lat)
camva(viewA_Start)

r_orbit = 900E3;
EarthAxes.XLim = [-1 1]*(erad+r_orbit);
EarthAxes.YLim = [-1 1]*(erad+r_orbit);
EarthAxes.ZLim = [-1 1]*(erad+r_orbit);

%% First Pan zoom from city to full view at Prime Meridian
Tspan = 30; % Seconds video Time
nSteps = Tspan*FPS;
MJD = MJD_Start;
for ii = 1:nSteps
    % Control the camera view
    va = (viewA_End - viewA_Start)*ii/nSteps + viewA_Start;
    el = (el_End - el_Start)*ii/nSteps + el_Start;
    az = (az_End - az_Start)*ii/nSteps + az_Start;
    camva(va)
    view(az, el)
    
    % Plot the Debris
    UpdateMJD;
    UpdateGlobe; % The CPU hates this function, only run when making final render
    if ii ~= nSteps
        CreateAvi(false)
    else
        CreateAvi(true)
    end
    pause(1/FPS);

    
    if mod(ii,10) == 0;
        disp(['Percent Complete: ' num2str(ii/nSteps)]);
    end
end

    function UpdateMJD
        persistent Run_UpdateMJD
        if isempty(Run_UpdateMJD)
            % First call of this function
            Run_UpdateMJD = true;
        else
            % Subsequent call, do nothing
        end
        MJD = MJD + SpeedRatio/(FPS*60*60*24);
    end

    function UpdateGlobe
            hgx = hgtransform;
            set(hgx,'Matrix', makehgtform('zrotate',GMST0+wrapTo2Pi(erot*MJD*24*60*60)));
            set(globe,'Parent',hgx);
    end

    function CreateAvi(FinalFrame)
        persistent CreateAVIFile
        frame = getframe(f);
        % Create the video
        if isempty(CreateAVIFile)
            CreateAVIFile = VideoWriter(AVI_Name, 'Motion JPEG AVI');
            CreateAVIFile.Quality = 100;
            CreateAVIFile.FrameRate = FPS;
            open(CreateAVIFile);
            writeVideo(CreateAVIFile,frame)
        elseif FinalFrame
            writeVideo(CreateAVIFile,frame)
            close(CreateAVIFile)
        else
            writeVideo(CreateAVIFile,frame)
            % Already created, do nothing
        end
    end
end


